import os, sys
import pygame

default_font_name = "Vera.ttf"
optimize = True

resource_dir = os.path.join(os.path.dirname(sys.path[0]), "Resources")

image_cache = {}
font_cache = {}
sound_cache = {}
text_cache = {}

def resource_path(*names):
	return os.path.join(resource_dir, *names)

def hex4(x):
	return "%08X" % x

def get_image(name, border = 0, optimize = optimize, noalpha = False):
	image = image_cache.get(name)
	if not image:
		image = pygame.image.load(resource_path("images", name))
		if noalpha:
			#print "Stripping alpha from:", name
			image = image.convert(24)
		elif optimize:
			#print "Before convert_alpha:", map(hex4, image.get_masks())
			image = image.convert_alpha()
		#print "Image %s: masks =" % name, map(hex4, image.get_masks())
		if border:
			w, h = image.get_size()
			b = border
			d = 2 * border
			image = image.subsurface(b, b, w - d, h - d)
		image_cache[name] = image
	return image

def get_font(size, name = default_font_name):
	key = (name, size)
	font = font_cache.get(key)
	if not font:
		path = resource_path("fonts", name)
		font = pygame.font.Font(path, size)
		font_cache[key] = font
	return font

def get_sound(name):
	if sound_cache is None:
		return None
	sound = sound_cache.get(name)
	if not sound:
		try:
			from pygame.mixer import Sound
		except ImportError, e:
			no_sound(e)
			return None
		path = resource_path("sounds", name)
		try:
			sound = Sound(path)
		except pygame.error, e:
			no_sound(e)
			return None
		sound_cache[name] = sound
	return sound

def no_sound(e):
	global sound_cache
	print "Albow.resource.get_sound:", e
	print "Albow.resource.get_sound: Running without sound"
	sound_cache = None

def get_text(name):
	text = text_cache.get(name)
	if text is None:
		path = resource_path("text", name)
		text = open(path, "rU").read()
		text_cache[name] = text
	return text

default_font = get_font(12)
