#
#   PROBE - Input form screen base
#

from pygame import draw, Rect
from albow.resource import get_font, get_image
from albow.controls import Label, TextField
from screen import ProbeScreen
import messages

class FormScreen(ProbeScreen):

	bg_image = get_image("desk-paper-a4-left-800x600.jpg")
	left_margin = 50
	top_margin = 50
	width = 350
	height = 400
	label_margin = left_margin + 20
	header_top = top_margin + 20
	fields_top = header_top + 100
	fields_top = header_top + 100
	field_margin = label_margin + 140
	field_spacing = 30
	fg_color = (50, 50, 50)
	input_color = (0, 0, 0)
	input_font = get_font(12, "VeraMono.ttf")
	small_font = get_font(9, "Vera.ttf")

	def __init__(self, shell):
		ProbeScreen.__init__(self, shell)
		self.input_fields = []
		self.add_header()

	def update(self):
		pass

	def add_label(self, x, y, text, font = None, align = 'left'):
		label = Label(text)
		attr = 'top' + align
		setattr(label.rect, attr, (x, y))
		if font:
			label.font = font
		self.add(label)
	
	def add_signature_field(self, i):
		field = TextField(50)
		self.signature_field = field
		self.add_input_field(i, "APPROVED", field)
		r = field.rect
		self.add_label(r.left, r.bottom + 8, "(Write initials here and press Enter)",
			font = self.small_font)
		field.enter_action = self.submit_form
	
	def add_input_field(self, i, caption, field, unit = None):
		self.input_fields.append(field)
		field.change_action = self.update
		self.add_field(i, caption, field, unit)
	
	def add_field(self, i, caption, field, unit = None):
		y = self.fields_top + i * self.field_spacing
		#label = Label(caption)
		#label.rect.topleft = (self.label_margin, y + 2)
		self.add_label(self.label_margin, y + 2, caption)
		field.rect.topleft = (self.field_margin, y)
		field.fg_color = self.input_color
		field.font = self.input_font
		#self.add(label)
		self.add(field)
		if unit:
			if unit.startswith("-"):
				self.add_label(field.rect.left - 5, field.rect.top + 2,
					unit[1:], align = 'right')
			else:
				self.add_label(field.rect.right + 5, field.rect.top + 2, unit)

	def draw(self, surf):
		color = self.fg_color
		frame = surf.get_rect()
		surf.blit(self.bg_image, (0, 0))
		r = Rect(self.left_margin, self.top_margin, self.width, self.height)
		draw.rect(surf, color, r, 1)
		for field in self.input_fields:
			r = field.rect
			y = r.bottom + 2
			draw.line(surf, color, (r.left, y), (r.right, y))

	def verify_signature(self):
		if self.signature_field.get_text() == "":
			self.signature_field.focus()
			return False
		else:
			return True

	def report_success(self, mess):
		messages.show_memo(True,
			self.memo_sender,
			self.memo_subject,
			mess)
		self.signature_field.set_text("")

	def report_error(self, mess):
		messages.show_memo(False,
			self.memo_sender,
			self.memo_subject,
			mess)
		self.signature_field.set_text("")
