#
#   PROBE - Image utilities
#

from pygame import Rect
from albow.resource import get_image

the_image_sets = {}

class ImageSet(object):

	def __init__(self, resource_name, num_rows, num_cols, border = 0):
		self.buffer = get_image(resource_name, border = border)
		self.num_rows = num_rows
		self.num_cols = num_cols
		buf_width, buf_height = self.buffer.get_size()
		cell_width = buf_width // num_cols
		cell_height = buf_height // num_rows
		self.cell_size = (cell_width, cell_height)
	
	def __getitem__(self, i):
		buf = self.buffer
		num_rows = self.num_rows
		num_cols = self.num_cols
		row, col = divmod(i, num_cols)
		cell_width, cell_height = self.cell_size
		r = Rect(col * cell_width, row * cell_height, cell_width, cell_height)
		return buf.subsurface(r)

def get_image_set(name, num_rows, num_cols, border = 0):
	result = the_image_sets.get(name)
	if not result:
		result = ImageSet(name, num_rows, num_cols, border)
		the_image_sets[name] = result
	return result
